pub struct LinkCapabilities {
pub attachment_backfill: bool,
pub spqr: bool,
pub username_change_sync_message: bool,
}Fields
attachment_backfill: boolspqr: boolSparse Post-Quantum Ratchet (SPARSE_POST_QUANTUM_RATCHET on Signal Server).
Required for all devices; the server returns 409 if a linking device omits this capability while the account already has it on any existing device.
username_change_sync_message: boolTrait Implementations
Sourceimpl Debug for LinkCapabilities
impl Debug for LinkCapabilities
Sourceimpl Default for LinkCapabilities
impl Default for LinkCapabilities